<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Administratortilgang kreves</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Denne handlingen krever administratortilgang. Start programmet på nytt og skriv inn passordet når du får beskjed.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Oppdaget live-miljø. Velg rotpartisjonen til det
systemet du vil endre (viser kun Linux-partisjoner)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Bruk forenklet menystruktur uten undermenyer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Bruk flate menyer (uten undermenyer)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Start opp til</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Velg «0» for å starte umiddelbart uten å vise menyen, eller «-1» for å avvente brukervalg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Tidsavbrudd for meny</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Kjerneparametre</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Slå på for å lagre valget i grub-menyen som forvalgt i framtidige oppstarter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Lagre sist valgte oppstart</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Behandle oppstartsalternativer for UEFI</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Bakgrunn</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Bilde</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Slå på tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Velkomstbilde</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Meldinger</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Dypt detaljert</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljert (forvalgt)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Begrenset</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Vis logg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Kjører fortsatt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <location filename="../src/mainwindow.cpp" line="390"/>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <location filename="../src/mainwindow.cpp" line="535"/>
        <location filename="../src/mainwindow.cpp" line="1359"/>
        <location filename="../src/mainwindow.cpp" line="1372"/>
        <location filename="../src/mainwindow.cpp" line="1378"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installerer oppstartsbilde, vennligst vent</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="156"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation>Forhåndsvisning er slått av fordi parameteren «splash» mangler fra kjernens oppstartsparametre. Legg til «splash» for å slå på forhåndsvisning ved neste omstart.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>Updating sources</source>
        <translation>Oppdaterer kilder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="390"/>
        <source>Could not install the bootsplash.</source>
        <translation>Klarte ikke installere oppstartsbilde.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="535"/>
        <source>Could not create a temporary folder</source>
        <translation>Klarte ikke å opprette midlertidig mappe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot continue</source>
        <translation>Kan ikke fortsette</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Klarte ikke åpne LUKS-enhet. Avslutter …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="565"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Klarte ikke opprette chroot-miljø og kan derfor ikke endre oppstartsalternativer. Avslutter …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="896"/>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Updating configuration, please wait</source>
        <translation>Oppdaterer oppsett – vennligst vent</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>Updating initramfs...</source>
        <translation>Oppdaterer initramfs …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="981"/>
        <location filename="../src/mainwindow.cpp" line="1290"/>
        <source>Updating grub...</source>
        <translation>Oppdaterer grub …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1006"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1007"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1009"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program for valg av vanlige oppstartsalternativer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1011"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1043"/>
        <location filename="../src/mainwindow.cpp" line="1252"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kjører i en virtuell maskin</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1044"/>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Systemet kjører i en virtuell maskin.
«Plymouth» oppstartsbilde har derfor begrenset virkeområde, og temaet kan ikke forhåndsvises.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1051"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-pakkene er ikke installerte</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1052"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-pakkene er ikke installerte.
Vil du installere dem nå?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1078"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Bilder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1220"/>
        <source>Log not found</source>
        <translation>Fant ikke logg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1220"/>
        <source>Could not find log at </source>
        <translation>Fant ikke loggen på</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1359"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Klarte ikke hente UUID for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1367"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Angi passord for å låse opp den krypterte partisjonen %1:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1372"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>Skriving av passord ble avbrutt eller er tom for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1378"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Klarte ikke åpne %1 LUKS-partisjon</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1209"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>En prosess kjører fortsatt. Vil du virkelig avslutte?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="176"/>
        <source>Live System Detected</source>
        <translation>Oppdaget livesystem</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="178"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Et livesystem kjører. Vil du endre oppstartsinnstillingene for livesystemet eller et installert system?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="180"/>
        <source>Live System</source>
        <translation>Livesystem</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Installed System</source>
        <translation>Installert system</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <source>Failed to update package sources.</source>
        <translation>Klarte ikke oppdatere pakkekilder.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="386"/>
        <source>Installing packages:</source>
        <translation>Installerer pakker:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Installerte Bootsplash.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>Failed to create temporary file.</source>
        <translation>Klarte ikke opprette midlertidig fil.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="989"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Du kjører i livemodus med valget «toram». Husk å lagre minnefila eller å remastre, ellers vil alle endringer bli tapt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="991"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Endringene er nå tatt i bruk.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="992"/>
        <source>Operation Complete</source>
        <translation>Handling fullført</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1077"/>
        <source>Select image to display in bootloader</source>
        <translation>Velg bilde som skal vises i oppstartslasteren</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1201"/>
        <source>Boot Log</source>
        <translation>Oppstartslogg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1241"/>
        <source>Needs reboot</source>
        <translation>Omstart kreves</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth ble nettopp installert. Omstart kreves for å kunne forhåndsvise temaer.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Click to select theme</source>
        <translation>Klikk for å velge tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1326"/>
        <source>Select GRUB theme</source>
        <translation>Velg Grub-tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program for valg av vanlige oppstartsalternativer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
</context>
</TS>